Stan Math Library: stan/math/prim/mat/fun/get_lp.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
get_lp.hpp File Reference
`#include <boost/math/tools/promotion.hpp>`
`#include <stan/math/prim/mat/fun/accumulator.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_lp , typename T_lp_accum >
boost::math::tools::promote_args< T_lp, T_lp_accum >::type | stan::math::get_lp (const T_lp &lp, const stan::math::accumulator< T_lp_accum > &lp_accum)

[ Stan Home Page ] © 2011–2016, Stan Development Team.